# serine

Serine Labs

## Installation

```bash
pip install serine
```
# Or using uv
```bash
uv pip install serine
```

## Usage

```python
import serine

print(serine.info())  # Output: serinelabs
```
